PySlice

Struct PySlice 

pub struct PySlice { /* private fields */ }
A wrapper around ndslice::Slice to expose it to python. It is a compact representation of indices into the flat representation of an n-dimensional array. Given an offset, sizes of each dimension, and strides for each dimension, Slice can compute indices into the flat array.